Module log

Module log 

Git log operation with comprehensive options.

This module provides the LogOpts builder pattern and log operation implementation for the GitGix service.

Structs

LogOpts
Options for log operation with builder pattern.

Functions

commit_touches_path
Check if a commit modifies the specified path.
log
Execute log operation with the given options, returning a stream of commits.