pub fn log(
repo: RepoHandle,
opts: LogOpts,
client_pwd: Option<&Path>,
) -> AsyncStream<GitResult<CommitInfo>>Expand description
Execute log operation with the given options, returning a stream of commits.
pub fn log(
repo: RepoHandle,
opts: LogOpts,
client_pwd: Option<&Path>,
) -> AsyncStream<GitResult<CommitInfo>>Execute log operation with the given options, returning a stream of commits.