pub async fn pull(repo: RepoHandle, opts: PullOpts) -> GitResult<PullResult>Expand description
Pull from remote (fetch + merge)
Note: The branch parameter should be the local branch name, not the remote tracking branch. This function will construct the remote tracking branch name (e.g., “origin/main”).