Async task and stream abstractions for GitGix operations.
Channel-based design for zero-allocation async coordination.
Structs
- Async
Stream - A handle to an asynchronous stream that produces multiple results.
- Async
Task - A handle to an asynchronous task that produces a single result.
- Emitter
Builder - Builder for converting batch API results into streams.